# Pythautomata

Pythautomata is a Python library for modeling finite state systems.

## **About**
Pythautomata is developed at the Department of Artificial Intelligence and Big Data of the Universidad ORT Uruguay. Its main goal is to provide implementations for the structures needed for working in the Model Extraction Framework.

Models present in the framework are:

- DFA
- NFA
- WFA/PDFA
- SFA

All of these can be exported in different manners, like pickle or to visual representations using Graphviz. Besides the structure representations a number of algorithms of interest are implemented, to name a few:

- FSA minimization
- FSA comparison using Hopcroft Karp equivalence
- FSA intersection (and other boolean operations)


## **Installation**

```
pip install pythautomata
```

## **Documentation**

- [**API Documentation:**](https://neuralchecker.github.io/pythautomata/index.html)


## **Maintainers**

Federico Vilensky

Franz Mayr

Federico Pan

## Colaborators


